@@ -8,7 +8,15 @@ Go on
 
 https://mypythontools.readthedocs.io/#project-starter
 
-for tutorial how to build such an app.
+for example with working examples.
+
+Image of such an app
+
+.. image:: /_static/project-starter-gui.png
+    :width: 620
+    :alt: project-starter-gui
+    :align: center
+
 """
 
 import os
@@ -251,14 +259,15 @@ def to_vue_plotly(data, names=None):
     }
 
 
-def to_table(df):
+def to_table(df, index=False):
     """Takes data (dataframe or numpy array) and transforms it to form, that vue-plotly library understands.
 
     Args:
-        df (pd.DataFrame): Data in table form
+        df (pd.DataFrame): Data.
+        index (bool): Whether use index as first column (or not at all).
 
     Returns:
-        dict: Data in form for create table.
+        dict: DatPa in form for creating table in Vuetify v-data-table.
     """
     data = df.copy()
     data = data.round(decimals=3)
@@ -266,6 +275,9 @@ def to_table(df):
     # Numpy nan cannot be send to json - replace with None
     data = data.where(~data.isin([np.nan, np.inf, -np.inf]), None)
 
+    if index:
+        data.reset_index(inplace=True)
+
     headers = [{"text": i, "value": i, "sortable": True} for i in data.columns]
 
     return {"table": data.to_dict("records"), "headers": headers}
